# Lightning HPO Examples

### 1. App Agnostic

This example shows you how to use Lightning HPO with any framework.

```bash
lightning run app examples/1_app_agnostic.py
```

### 2. App PyTorch Lightning

This example shows you how to use Lightning HPO with [PyTorch Lightning](https://pytorch-lightning.readthedocs.io/en/stable/) framework.

```bash
lightning run app examples/examples/2_app_pytorch_lightning.py
```

### 3. App Sklearn

This example shows you how to use Lightning HPO with sklearn and advanced pruning example

```bash
lightning run app examples/examples/3_app_sklearn.py
```
